@@ -732,6 +732,9 @@ sub buildCookie {
                 name   => $self->conf->{cookieName},
                 value  => $req->id,
                 secure => $self->conf->{securedCookie},
+                $self->conf->{cookieExpiration}
+                ? ( max_age => $self->conf->{cookieExpiration} )
+                : (),
             )
         );
         if ( $self->conf->{securedCookie} >= 2 ) {
@@ -741,6 +744,9 @@ sub buildCookie {
                     name   => $self->conf->{cookieName} . "http",
                     value  => $req->{sessionInfo}->{_httpSession},
                     secure => 0,
+                    $self->conf->{cookieExpiration}
+                    ? ( max_age => $self->conf->{cookieExpiration} )
+                    : (),
                 )
             );
         }
