@@ -7,10 +7,10 @@ use Lemonldap::NG::Portal::Main::Constants qw(
   PE_MISSINGREQATTR
 );
 
-our $VERSION = '2.0.12';
+our $VERSION = '2.19.0';
 
 extends qw(
-  Lemonldap::NG::Common::Module
+  Lemonldap::NG::Portal::Main::UserDB
   Lemonldap::NG::Portal::Lib::OpenIDConnect
 );
 
@@ -59,9 +59,4 @@ sub setSessionInfo {
     return PE_OK;
 }
 
-# Does nothing
-sub setGroups {
-    return PE_OK;
-}
-
 1;
