@@ -444,7 +444,7 @@
     // 	cookie:
     // 		name: 'lemonldapauthchoice'
     if (datas['choicetab']) {
-      authMenuTabs.tabs("option", "active", $('#authMenu a[href="#' + datas['choicetab'] + '"]').parent().index());
+      authMenuTabs.tabs("option", "active", $('#authMenu a[href="#id_' + datas['choicetab'] + '"]').parent().index());
     }
     // If there are no auto-focused fields, focus on first visible input
     if ($("input[autofocus]").length === 0) {
@@ -773,11 +773,13 @@
     $(".category[name=\"".concat(datas['floatingCategory'], "\"]")).appendTo('#floating-menu').find("i").remove();
     $(".category[name=\"".concat(datas['floatingCategory'], "\"]")).draggable();
     var parent = document.getElementById('floating-menu');
-    var divs = parent.querySelectorAll('.col-md-4');
-    divs.forEach(function (div, index) {
-      div.classList.remove("col-md-4");
-      div.classList.add("col-md-12");
-    });
+    if (parent) {
+      var divs = parent.querySelectorAll('.col-md-4');
+      divs.forEach(function (div, index) {
+        div.classList.remove("col-md-4");
+        div.classList.add("col-md-12");
+      });
+    }
     $(document).trigger("portalLoaded");
     return true;
   });
